@@ -1,11 +1,11 @@
-out1 <- toyModel(model="dNMF")
-out2 <- toyModel(model="dSVD")
-out3 <- toyModel(model="dNTF")
-out4 <- toyModel(model="dNTD")
-out5 <- toyModel(model="dsiNMF_Easy")
-out6 <- toyModel(model="dsiNMF_Hard")
-out7 <- toyModel(model="PLS_Easy")
-out8 <- toyModel(model="PLS_Hard")
+out1 <- dcTensor::toyModel(model="dNMF")
+out2 <- dcTensor::toyModel(model="dSVD")
+out3 <- dcTensor::toyModel(model="dNTF")
+out4 <- dcTensor::toyModel(model="dNTD")
+out5 <- dcTensor::toyModel(model="dsiNMF_Easy")
+out6 <- dcTensor::toyModel(model="dsiNMF_Hard")
+out7 <- dcTensor::toyModel(model="dPLS_Easy")
+out8 <- dcTensor::toyModel(model="dPLS_Hard")
 
 expect_equivalent(length(dim(out1)), 2)
 expect_equivalent(length(dim(out2)), 2)
